"""Module contains helpers for working with environment variables."""

import os

from configs_core.constants import (
    DEFAULT_NESTED_DELIMITER,
    LUNA_CONFIGURATOR,
    LUNA_CONFIGURATOR_API,
    LUNA_CONFIGURATOR_ORIGIN,
    LUNA_CONFIGURATOR_PASS,
    LUNA_CONFIGURATOR_USER,
    USE_CONFIGURATOR,
    VL_SETTINGS,
)


def getEnvDelimiter() -> str:
    """Get environment delimiter"""
    return os.getenv("VL_SETTINGS_NESTED_DELIMITER", DEFAULT_NESTED_DELIMITER)


class _ConfiguratorEnvCreds:
    """
    Configurator environment credentials container
    """

    def __init__(self):
        delimiter = getEnvDelimiter()
        self.useConfigurator = int(
            os.getenv(f"{VL_SETTINGS}{delimiter}{LUNA_CONFIGURATOR}{delimiter}{USE_CONFIGURATOR}", "0")
        )
        self.configuratorOrigin = os.getenv(
            f"{VL_SETTINGS}{delimiter}{LUNA_CONFIGURATOR}{delimiter}{LUNA_CONFIGURATOR_ORIGIN}"
        )
        self.configuratorApi = os.getenv(
            f"{VL_SETTINGS}{delimiter}{LUNA_CONFIGURATOR}{delimiter}{LUNA_CONFIGURATOR_API}"
        )
        self.configuratorUser = os.getenv(
            f"{VL_SETTINGS}{delimiter}{LUNA_CONFIGURATOR}{delimiter}{LUNA_CONFIGURATOR_USER}"
        )
        self.configuratorPass = os.getenv(
            f"{VL_SETTINGS}{delimiter}{LUNA_CONFIGURATOR}{delimiter}{LUNA_CONFIGURATOR_PASS}"
        )


def getConfiguratorEnvCreds() -> _ConfiguratorEnvCreds:
    """
    Get container with environment specification credentials to luna-configurator.

    This creds are not module constants because for tests needs change env on fly.

    Different between getConfiguratorEnvCreds() and _ConfiguratorEnvCreds() is semantic only.
    """
    return _ConfiguratorEnvCreds()
